@@ -50,7 +50,7 @@ async def eval_code(
     return [result[i: i + 2000] for i in range(0, len(result), 2000)]
 
 
-class EvalView(View):
+class Eval(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
